package com.hcordova.flightagencyapi.agent.controllers;

import java.util.List;

import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.hcordova.flightagencyapi.agent.domain.services.AgentService;
import com.hcordova.flightagencyapi.agent.dto.AgentAllDTO;
import com.hcordova.flightagencyapi.agent.dto.AgentByDTO;
import com.hcordova.flightagencyapi.agent.dto.AgentEditDTO;

import lombok.RequiredArgsConstructor;

@CrossOrigin(origins = "http://localhost:4200")
@RestController
@RequestMapping("/api/v1/agents")
@RequiredArgsConstructor
public class AgentController {
    private final AgentService agentService;

    @GetMapping()
    public ResponseEntity<List<AgentAllDTO>> getAll() {
        return ResponseEntity.ok(agentService.getAll().stream().map(agent -> {
            return new AgentAllDTO(agent);
        }).toList());
    }

    @GetMapping("{id}")
    public ResponseEntity<AgentByDTO> getById(@PathVariable() Long id) {
        return ResponseEntity.ok(new AgentByDTO(agentService.getById(id)));
    }

    @PutMapping("{id}")
    public ResponseEntity<AgentByDTO> edit(@PathVariable Long id, @RequestBody() AgentEditDTO editDTO) {
        return ResponseEntity.ok(new AgentByDTO(agentService.edit(editDTO, id)));
    }

    @DeleteMapping("{id}")
    public ResponseEntity<AgentByDTO> delete(@PathVariable Long id) {
        return ResponseEntity.ok(new AgentByDTO(agentService.delete(id)));
    }
}
