package com.hcordova.flightagencyapi.agent.services;

import java.time.LocalDate;
import java.util.List;

import org.springframework.stereotype.Service;

import com.hcordova.flightagencyapi.agent.domain.models.Agent;
import com.hcordova.flightagencyapi.agent.domain.repositories.AgentRepository;
import com.hcordova.flightagencyapi.agent.domain.services.AgentService;
import com.hcordova.flightagencyapi.agent.dto.AgentEditDTO;
import com.hcordova.flightagencyapi.shared.exceptions.NotFoundException;

import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
public class AgentServiceImpl implements AgentService {

    private final AgentRepository agentRepository;

    @Override
    public List<Agent> getAll() {
        return agentRepository.findAllByDeletedAtIsNull();
    }

    @Override
    public Agent getById(Long id) {
        return agentRepository.findByIdAndDeletedAtIsNull(id)
            .orElseThrow(() -> new NotFoundException("Agent not found"));
    }

    @Override
    public Agent edit(AgentEditDTO agent, Long id) {
        Agent agentToEdit = getById(id);
        agentToEdit.setDetails(agent.getDetails());
        return agentRepository.save(agentToEdit);
    }

    @Override
    public Agent delete(Long id) {
        Agent agent = getById(id);
        agent.setDeletedAt(LocalDate.now());
        return agentRepository.save(agent);
    }
    
}
