package com.hcordova.flightagencyapi.flight.controllers;

import java.util.List;

import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.hcordova.flightagencyapi.flight.domain.services.FlightScheduleService;
import com.hcordova.flightagencyapi.flight.dto.FlightAllDTO;
import com.hcordova.flightagencyapi.flight.dto.FlightByDTO;
import com.hcordova.flightagencyapi.flight.dto.FlightSaveDTO;
import com.hcordova.flightagencyapi.flight.dto.FlightSearchDTO;

import lombok.RequiredArgsConstructor;

@CrossOrigin(origins = "*")
@RestController
@RequestMapping("/api/v1/flights")
@RequiredArgsConstructor
public class FlightScheduleController {
    
    private final FlightScheduleService flightScheduleService;


    @GetMapping()
    public ResponseEntity<List<FlightAllDTO>> getAll() {
        System.out.print("getAll");
        return ResponseEntity.ok(flightScheduleService.getAll().stream().map(flight -> {
            return new FlightAllDTO(flight);
        }).toList());
    }

    @GetMapping("{id}")
    public ResponseEntity<FlightByDTO> getById(@PathVariable Long id) {
        return ResponseEntity.ok(new FlightByDTO(flightScheduleService.getById(id)));
    }

    @GetMapping("/search")
    public ResponseEntity<List<FlightSearchDTO>> searchFlight(@RequestParam(name = "airportOriginId") Long origin, 
        @RequestParam(name = "airportDestinationId") Long destination, @RequestParam(name = "startDate") String startDate)  {
        return ResponseEntity.ok(flightScheduleService.searchByOriginDestinationAndDate(origin, destination, startDate).stream().map(flight -> new FlightSearchDTO(flight, startDate)).toList());
    }

    @PostMapping
    public ResponseEntity<FlightAllDTO> save(@RequestBody FlightSaveDTO saveDTO) {
        return ResponseEntity.ok(new FlightAllDTO(flightScheduleService.save(saveDTO)));
    }

    @DeleteMapping("{id}")
    public ResponseEntity<FlightAllDTO> delete(@PathVariable Long id) {
        return ResponseEntity.ok(new FlightAllDTO(flightScheduleService.delete(id)));
    }
}
