package com.hcordova.flightagencyapi.flight.domain.models;

import java.io.Serializable;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

import com.hcordova.flightagencyapi.aircraft.domain.models.Aircraft;
import com.hcordova.flightagencyapi.airline.domain.models.Airline;
import com.hcordova.flightagencyapi.airport.domain.models.Airport;

import jakarta.persistence.Access;
import jakarta.persistence.AccessType;
import jakarta.persistence.CascadeType;
import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.FetchType;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.GenerationType;
import jakarta.persistence.Id;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.ManyToOne;
import jakarta.persistence.OneToMany;
import jakarta.persistence.Table;
import jakarta.persistence.Temporal;
import jakarta.persistence.TemporalType;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Entity
@Table(name = "flight_schedules")
@Getter
@Setter
@AllArgsConstructor
@NoArgsConstructor
public class FlightSchedule implements Serializable {
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    @ManyToOne(optional = false, cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    private Airline airline;

    @ManyToOne(optional = false, cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    private Aircraft aircraft;

    @ManyToOne(optional = false)
    @JoinColumn(name = "airport_origin_id", referencedColumnName = "id")
    @Access(AccessType.FIELD)
    private Airport airportOrigin;

    @ManyToOne(optional = false, cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    private Airport airportDestination;

    @Column(nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private LocalDateTime departureDateTime;

    @Column(nullable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private LocalDateTime arrivalDateTime;

    @OneToMany(mappedBy = "flightSchedule", cascade = CascadeType.ALL)
    List<Leg> legs;

    @OneToMany(mappedBy = "flightSchedule", cascade = CascadeType.ALL)
    List<FlightCost> costs;

    @Column(nullable = true)
    @Temporal(TemporalType.DATE)
    public LocalDate deletedAt;
}
