package com.hcordova.flightagencyapi.flight.dto;

import java.time.Duration;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

import com.hcordova.flightagencyapi.flight.domain.models.FlightCost;
import com.hcordova.flightagencyapi.flight.domain.models.FlightSchedule;
import com.hcordova.flightagencyapi.flight.domain.models.Leg;

import lombok.Getter;
import lombok.Setter;

@Getter
@Setter
public class FlightSearchDTO {
    private Long id;
    private String airline;
    private String aircraft;
    private String airportOrigin;
    private String airportDestination;
    private String flightType;
    private String departureDate;
    private String arrivalDate;
    private Double price;
    private List<LegDTO> legs;

    public FlightSearchDTO(FlightSchedule flightSchedule, String startDate) {
        this.id = flightSchedule.getId();

        LocalDate dateToCheck = LocalDate.parse(startDate);

        FlightCost flightCost = new FlightCost();

        for (FlightCost cost : flightSchedule.getCosts()) {
            if ((dateToCheck.isAfter(cost.getDateStart()) && dateToCheck.isBefore(cost.getDateEnd())) || 
                dateToCheck.isEqual(cost.getDateStart()) || dateToCheck.isEqual(cost.getDateEnd())) {
                flightCost = cost;
            }
        }

        this.airportOrigin = flightSchedule.getAirportOrigin().getName();
        this.airportDestination = flightSchedule.getAirportDestination().getName();

        LocalDateTime legDeparture = flightSchedule.getLegs().stream().findFirst().get().getActualDeparture();
        LocalDateTime legArrival = flightSchedule.getLegs().get(flightSchedule.getLegs().size() - 1).getActualArrival();

        Duration duration = java.time.Duration.between(legDeparture, legArrival);

        LocalDateTime departureDateTime = LocalDateTime.of(LocalDate.parse(startDate), flightSchedule.getDepartureDateTime().toLocalTime());
        LocalDateTime arrivalDateTime = departureDateTime.plus(duration);

        calculateDates(flightSchedule.getLegs(), startDate);

        this.departureDate = departureDateTime.toString();
        this.arrivalDate = arrivalDateTime.toString();
        this.airline = flightSchedule.getAirline().getName();
        this.aircraft = flightSchedule.getAircraft().getName();
        this.flightType = flightSchedule.getLegs().size() > 1 ? "Round Trip" : "One Way";
        this.price = flightCost.getCost();
        this.legs = flightSchedule.getLegs().stream().map(leg -> {
            return new LegDTO(leg);
        }).toList();
    }

    private void calculateDates(List<Leg> legs, String startDate) {
        LocalDate start = LocalDate.parse(startDate);
        for (int i = 0; i < legs.size(); i++) {
            Leg leg = legs.get(i);
            if (i == 0) {
                leg.setActualDeparture(LocalDateTime.of(start, leg.getActualDeparture().toLocalTime()));
                leg.setActualArrival(LocalDateTime.of(start, leg.getActualArrival().toLocalTime()));
            } else {
                Duration durationDeparture = Duration.between(leg.getActualDeparture(), legs.get(i - 1).getActualArrival());
                Duration durationArrival = Duration.between(leg.getActualDeparture(), leg.getActualArrival());
                leg.setActualArrival(leg.getActualDeparture().plus(durationArrival));
                leg.setActualDeparture(legs.get(i - 1).getActualArrival().plus(durationDeparture));
            }
        }
    }
}
