package com.hcordova.flightagencyapi.passenger.controllers;

import java.util.List;

import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.hcordova.flightagencyapi.passenger.domain.services.PassengerService;
import com.hcordova.flightagencyapi.passenger.dto.PassengerByDTO;
import com.hcordova.flightagencyapi.passenger.dto.PassengerEditDTO;
import com.hcordova.flightagencyapi.passenger.dto.PassengerTableDTO;

import lombok.RequiredArgsConstructor;

@CrossOrigin(origins = "*")
@RestController
@RequestMapping("/api/v1/passengers")
@RequiredArgsConstructor
public class PassengerController {
    private final PassengerService passengerService;

    @GetMapping
    public ResponseEntity<List<PassengerTableDTO>> getAll() {
        return ResponseEntity.ok(passengerService.getAll().stream().map(passenger -> {
            return new PassengerTableDTO(passenger);
            }).toList());
    }

    @GetMapping("{id}")
    public ResponseEntity<PassengerByDTO> getById(@PathVariable() Long id) {
        return ResponseEntity.ok(new PassengerByDTO(passengerService.getById(id)));
    }

    @PutMapping("{id}")
    public ResponseEntity<PassengerByDTO> edit(@RequestBody() PassengerEditDTO passengerEditDTO, @PathVariable() Long id) {
        return ResponseEntity.ok(new PassengerByDTO(passengerService.edit(passengerEditDTO, id)));
    }

    @DeleteMapping("{id}")
    public ResponseEntity<PassengerByDTO> delete(@PathVariable() Long id) {
        return ResponseEntity.ok(new PassengerByDTO(passengerService.delete(id)));
    }
}
