package com.hcordova.flightagencyapi.passenger.services;

import java.time.LocalDate;
import java.util.List;

import org.springframework.stereotype.Service;

import com.hcordova.flightagencyapi.passenger.domain.models.Passenger;
import com.hcordova.flightagencyapi.passenger.domain.repositories.PassengerRepository;
import com.hcordova.flightagencyapi.passenger.domain.services.PassengerService;
import com.hcordova.flightagencyapi.passenger.dto.PassengerEditDTO;
import com.hcordova.flightagencyapi.shared.exceptions.NotFoundException;

import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
public class PassengerServiceImpl implements PassengerService {

    private final PassengerRepository passengerRepository;

    @Override
    public List<Passenger> getAll() {
        return passengerRepository.findAllByDeletedAtIsNull();
    }

    @Override
    public Passenger getById(Long id) {
        return passengerRepository.findByIdAndDeletedAtIsNull(id)
            .orElseThrow(() -> new NotFoundException("Passenger not found"));
    }

    @Override
    public Passenger edit(PassengerEditDTO passenger, Long id) {

        Passenger passengerToUpdate = passengerRepository.findById(id).orElse(null);

        if (passengerToUpdate == null) 
            throw new NotFoundException("Passenger not found");

        passengerToUpdate.setPhone(passenger.getPhone());
        passengerToUpdate.setCountry(passenger.getCountry());
        passengerToUpdate.setCity(passenger.getCity());
        passengerToUpdate.setAddress(passenger.getAddress());

        return passengerRepository.save(passengerToUpdate);
    }

    @Override
    public Passenger delete(Long id) {
        Passenger passengerToDelete = getById(id);
        passengerToDelete.setDeletedAt(LocalDate.now());
        passengerRepository.save(passengerToDelete);
        return passengerToDelete;
    }
    
}
