package com.hcordova.flightagencyapi.reservation.controllers;

import java.util.List;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.hcordova.flightagencyapi.reservation.domain.services.ReservationService;
import com.hcordova.flightagencyapi.reservation.dto.ReservationDTO;
import com.hcordova.flightagencyapi.reservation.dto.ReservationExtendedDTO;
import com.hcordova.flightagencyapi.reservation.dto.ReservationPassengerDTO;
import com.hcordova.flightagencyapi.reservation.dto.ReservationSaveDTO;

import lombok.RequiredArgsConstructor;

@RestController
@RequestMapping("/api/v1/reservations")
@RequiredArgsConstructor
public class ReservationController {
    private final ReservationService reservationService;

    @GetMapping
    public List<ReservationDTO> getAll() {
        return reservationService.getAll().stream().map(reservation -> {
            return new ReservationDTO(reservation);
        }).toList();
    }

    @GetMapping("/passenger/{id}")
    public List<ReservationPassengerDTO> getByPassengerId(@PathVariable Long id) {
        return reservationService.getByPassengerId(id).stream().map(reservation -> {
            return new ReservationPassengerDTO(reservation);
        }).toList();
    }

    @PutMapping("/pay/{id}")
    public ReservationPassengerDTO payReservation(@PathVariable Long id) {
        return new ReservationPassengerDTO(reservationService.payReservation(id));
    }

    @GetMapping("{id}")
    public ReservationExtendedDTO getById(@PathVariable Long id) {
        return new ReservationExtendedDTO(reservationService.getById(id));
    }

    @PostMapping
    public ReservationDTO save(@RequestBody ReservationSaveDTO reservationDTO) {
        return new ReservationDTO(reservationService.save(reservationDTO));
    }

    @PutMapping("/cancel/{id}")
    public ReservationDTO cancelReservation(@PathVariable Long id) {
        return new ReservationDTO(reservationService.cancelReservation(id));
    }

    @DeleteMapping("{id}")
    public ReservationDTO delete(@PathVariable Long id) {
        return new ReservationDTO(reservationService.deleteReservation(id));
    }
}
