package com.hcordova.flightagencyapi.reservation.domain.models;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;

import com.hcordova.flightagencyapi.agent.domain.models.Agent;
import com.hcordova.flightagencyapi.flight.domain.models.Leg;
import com.hcordova.flightagencyapi.passenger.domain.models.Passenger;

import jakarta.persistence.CascadeType;
import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.FetchType;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.GenerationType;
import jakarta.persistence.Id;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.JoinTable;
import jakarta.persistence.ManyToMany;
import jakarta.persistence.ManyToOne;
import jakarta.persistence.OneToOne;
import jakarta.persistence.Table;
import jakarta.persistence.Temporal;
import jakarta.persistence.TemporalType;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Entity
@Table(name = "reservations")
@Getter
@Setter
@AllArgsConstructor
@NoArgsConstructor
public class Reservation {
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    @ManyToOne(optional = false, cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    private Agent agent;

    @ManyToOne(optional = false, cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    private Passenger passenger;

    @ManyToOne(optional = false, cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    private ReservationStatus status;

    @ManyToOne(optional = false, cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    private TicketType ticketType;

    @ManyToOne(optional = false, cascade = CascadeType.ALL, fetch = FetchType.EAGER)
    private TravelClass travelClass;

    @Column(nullable = false)
    @Temporal(TemporalType.DATE)
    private LocalDate createdAt;

    @OneToOne(optional = false, cascade = CascadeType.ALL)
    private Payment payment;

    @ManyToMany(cascade = CascadeType.ALL)
    @JoinTable(name = "reservations_legs", 
        joinColumns = @JoinColumn(name = "reservation_id", referencedColumnName = "id"), 
        inverseJoinColumns = @JoinColumn(name = "leg_id", referencedColumnName = "id"))
    private List<Leg> legs = new ArrayList<>();

    @Column(nullable = true)
    @Temporal(TemporalType.DATE)
    private LocalDate deletedAt;

}
