package com.hcordova.flightagencyapi.reservation.dto;

import java.util.List;

import com.hcordova.flightagencyapi.flight.dto.LegDTO;
import com.hcordova.flightagencyapi.reservation.domain.models.Reservation;

import lombok.Getter;

@Getter
public class ReservationExtendedDTO {
    private Long id;
    private Long passengerId;
    private String passenger;
    private String ticketType;
    private Long airportOriginId;
    private String airportOrigin;
    private Long airportDestinationId;
    private String airportDestination;
    private String departureDate;
    private Long ticketTypeId;
    private String travelClass;
    private Long travelClassId;
    private Long flightId;
    private String status;
    List<LegDTO> legs;

    public ReservationExtendedDTO(Reservation reservation) {
        this.id = reservation.getId();
        this.passengerId = reservation.getPassenger().getId();
        this.passenger = reservation.getPassenger().getUser().getName() + " " + reservation.getPassenger().getUser().getLastname();
        this.ticketType = reservation.getTicketType().getName();
        this.ticketTypeId = reservation.getTicketType().getId();
        this.airportOriginId = reservation.getLegs().get(0).getFlightSchedule().getAirportOrigin().getId();
        this.airportDestinationId = reservation.getLegs().get(0).getFlightSchedule().getAirportDestination().getId();
        this.departureDate = reservation.getLegs().get(0).getFlightSchedule().getDepartureDateTime().toLocalDate().toString();
        this.travelClass = reservation.getTravelClass().getName();
        this.travelClassId = reservation.getTravelClass().getId();
        this.airportOrigin = reservation.getLegs().get(0).getFlightSchedule().getAirportOrigin().getName();
        this.airportDestination = reservation.getLegs().get(0).getFlightSchedule().getAirportDestination().getName();
        this.status = convertStatus(reservation.getStatus().getName());
        this.flightId = reservation.getLegs().get(0).getFlightSchedule().getId();
        this.legs = reservation.getLegs().stream().map(leg -> {
            return new LegDTO(leg);
        }).toList();
    }

    private String convertStatus(String status) {
        switch (status) {
            case "registered":
                return "Registrado";
            case "processing_payment":
                return "Procesando pago";
            case "paid":
                return "Pagado";
            case "cancelled":
                return "Cancelado";
            default:
                return "";
        }
    }
}
