import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { TableModel } from 'src/app/shared/interfaces/table-model.interface';
import { AirportsService } from '../../services/airports.service';
import { Airport } from '../../interfaces/airport.interface';
import { FlightService } from 'src/app/supervisor/services/flight.service';
import { FormControl, FormGroup, Validators } from '@angular/forms';
import { Flight } from 'src/app/supervisor/interfaces/flight.interface';

@Component({
  selector: 'agent-flight-information',
  templateUrl: './flight-information.component.html',
  styleUrls: ['./flight-information.component.css']
})
export class FlightInformationComponent implements OnInit {

  @Input()
  public flightModel: TableModel[] = [];

  public airportModel: TableModel[] = [
    {
      name: 'id',
      title: '#'
    },
    {
      name: 'name',
      title: 'Nombre'
    },
    {
      name: 'location',
      title: 'Ubicacion'
    },
    {
      name: 'code',
      title: 'Codigo'
    }
  ];

  public flightResults: Flight[] = [];

  @Input()
  public group: FormGroup = new FormGroup({
    airportOrigin: new FormControl<number | null>(null),
    airportDestination: new FormControl<number | null>(null),
    date: new FormControl<string | null>(null)
  });

  get airportOriginControl(): FormControl<number | null> {
    return this.group.get('airportOrigin') as FormControl<number | null>;
  }

  get airportDestinationControl(): FormControl<number | null> {
    return this.group.get('airportDestination') as FormControl<number | null>;
  }

  get dateControl(): FormControl<string | null> {
    return this.group.get('date') as FormControl<string | null>;
  }

  get airportOriginName(): string {
    const airport = this.airports.find(airport => airport.id === this.airportOriginControl.value);
    return airport?.name || '';
  }

  public airports: Airport[] = [];

  constructor(
    private airpotsService: AirportsService,
    private flightService: FlightService) { }

  ngOnInit(): void {
    this.airpotsService.getAll()
      .subscribe(airports => this.airports = airports);

    if (this.group.value.airportOrigin !== null && this.group.value.airportDestination !== null && this.group.value.date !== null) {
      this.flightService.searchFlight(this.group.value.airportOrigin, this.group.value.airportDestination, this.group.value.date)
        .subscribe(flights => {
          this.flightResults = flights;
        });
    }

    this.flightSelected ? this.flightResults.push(this.flightSelected) : [];
  }

  onSearchFlights(): void {
    const formValues = this.group.value;
    this.flightService.searchFlight(formValues.airportOrigin, formValues.airportDestination, formValues.date)
      .subscribe(flights => {
        console.log(flights);
        this.flightResults = flights;
      });
  }

  @Output()
  public onSelectFlight: EventEmitter<Flight> = new EventEmitter<Flight>();

  @Input()
  public flightSelected: Flight | null = null;

  onEventSelectFlight(flight: Flight): void {
    this.flightSelected = flight;
    this.onSelectFlight.emit(flight);
  }
}
