import { Component, OnInit } from '@angular/core';
import { TableModel } from 'src/app/shared/interfaces/table-model.interface';
import { ResultDelete } from 'src/app/shared/interfaces/result-delete.interface';
import { Reservation } from '../../interfaces/reservation.interface';
import { ReservationsService } from '../../services/reservations.service';
import { TableAction } from 'src/app/shared/interfaces/table-action.interface';
import { Router } from '@angular/router';

@Component({
  selector: 'app-reservations',
  templateUrl: './reservations.component.html',
  styleUrls: ['./reservations.component.css']
})
export class ReservationsComponent implements OnInit{

  tableData: Reservation[] = [];

  openDeleteDialog: boolean = false;
  openCancelDialog: boolean = false;

  actions: TableAction[] = [
    {
      title: 'Editar',
      icon: 'bi-pencil-square',
      disabled: (item) => item.status === 'Pagado',
      action: (item) => { this.router.navigate(['/agents/reservations/edit', item.id]);  }
    },
    {
      title: 'Eliminar',
      icon: 'bi-trash',
      disabled: (item) => item.status === 'Pagado',
      action: (item) => { this.openDeleteDialog = true; this.reservationSelected = item; }
    },
    {
      title: "Cancelar",
      icon: "bi-x-circle",
      disabled: (item) => item.status === 'Pagado' || item.status === 'Cancelado',
      action: (item) => { this.openCancelDialog = true; this.reservationSelected = item; }
    }
  ]

  reservationSelected: Reservation | null = null;

  tableModel: TableModel[] = [
    {
      name: 'id',
      title: '#'
    },
    {
      name: 'passenger',
      title: 'Pasajero'
    },
    {
      name: 'ticketType',
      title: 'Tipo de ticket'
    },
    {
      name: 'travelClass',
      title: 'Clase de viaje'
    },
    {
      name: 'status',
      title: 'Estado'
    }
  ];

  constructor(private reservationsService: ReservationsService,
    private router: Router) { }

  ngOnInit(): void {
    this.getAll();
  }

  getAll(): void {
    this.reservationsService.getAll()
      .subscribe(bookings => this.tableData = bookings);
  }

  onDelete(result: ResultDelete): void {
    if (!result.result) return;
    this.reservationsService.delete(result.id)
      .subscribe(() => this.getAll());
  }

  onHandlerResult(result: boolean): void {
    if (result) {
      this.reservationsService.delete(this.reservationSelected?.id!)
        .subscribe(() => this.getAll());
    }
    this.openDeleteDialog = false;
  }

  onHandleCancel(result: boolean): void {
    if (result) {
      this.reservationsService.cancelReservation(this.reservationSelected?.id!)
        .subscribe(() => this.getAll());
    }
    this.openCancelDialog = false;
  }
}
