import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Passenger } from '../interfaces/passenger.interface';
import { Observable } from 'rxjs';
import { headers } from 'src/app/shared/utils/header.util';
import { environment } from 'src/environments/environment';

@Injectable({providedIn: 'root'})
export class PassengerService {
  constructor(private http: HttpClient) { }

  URL_BASE: string = `${environment.url}/api/v1/passengers`;

  getAll(): Observable<Passenger[]> {
    return this.http.get<Passenger[]>(this.URL_BASE, { headers });
  }

  getById(id: number): Observable<Passenger> {
    return this.http.get<Passenger>(`${this.URL_BASE}/${id}`, { headers });
  }

  save(passenger: Passenger): Observable<Passenger> {
    return this.http.post<Passenger>(this.URL_BASE, passenger, { headers });
  }

  edit(id: number, passenger: Passenger): Observable<Passenger> {
    return this.http.put<Passenger>(`${this.URL_BASE}/${id}`, passenger, { headers });
  }

  delete(id: number): Observable<Passenger> {
    return this.http.delete<Passenger>(`${this.URL_BASE}/${id}`, { headers });
  }
}
