import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Reservation } from '../interfaces/reservation.interface';
import { Observable, tap } from 'rxjs';
import { headers } from 'src/app/shared/utils/header.util';
import { ReservationSave } from '../interfaces/reservation-save.interface';
import { ReservationDetail } from 'src/app/passenger/interfaces/reservation-detail.interface';
import { environment } from 'src/environments/environment';

@Injectable({providedIn: 'root'})
export class ReservationsService {
  constructor(private http: HttpClient) { }

  URL_BASE: string = `${environment.url}/api/v1/reservations`;

  getAll(): Observable<Reservation[]> {
    return this.http.get<Reservation[]>(this.URL_BASE, { headers});
  }

  getById(id: number): Observable<Reservation> {
    return this.http.get<Reservation>(`${this.URL_BASE}/${id}`, { headers });
  }

  getByPassengerId(id: number): Observable<ReservationDetail[]> {
    return this.http.get<ReservationDetail[]>(`${this.URL_BASE}/passenger/${id}`, { headers });
  }

  payReservation(id: number): Observable<ReservationDetail> {
    return this.http.put<ReservationDetail>(`${this.URL_BASE}/pay/${id}`, null, { headers });
  }

  cancelReservation(id: number): Observable<ReservationDetail> {
    return this.http.put<ReservationDetail>(`${this.URL_BASE}/cancel/${id}`, null, { headers });
  }

  save(reservation: ReservationSave): Observable<Reservation> {
    return this.http.post<Reservation>(this.URL_BASE, reservation, { headers });
  }

  edit(id: number, reservation: Reservation): Observable<Reservation> {
    return this.http.put<Reservation>(`${this.URL_BASE}/${id}`, reservation);
  }

  delete(id: number): Observable<Reservation> {
    return this.http.delete<Reservation>(`${this.URL_BASE}/${id}`, { headers });
  }
}
