import { Component, OnInit } from '@angular/core';
import { TableModel } from 'src/app/shared/interfaces/table-model.interface';
import { ReservationDetail } from '../../interfaces/reservation-detail.interface';
import { TableAction } from 'src/app/shared/interfaces/table-action.interface';
import { Router } from '@angular/router';
import { FormControl, FormGroup, Validators } from '@angular/forms';
import { ReservationsService } from 'src/app/agent/services/reservations.service';
import { SecurityService } from 'src/app/security/services/security.service';

@Component({
  selector: 'passenger-my-reservations',
  templateUrl: './my-reservations.component.html',
  styleUrls: ['./my-reservations.component.css']
})
export class MyReservationsComponent implements OnInit {

  public actions: TableAction[] = [
    {
      title: 'Editar',
      icon: 'bi-pencil-square',
      disabled: (_) => true,
      action: (_) => {  }
    },
    {
      title: 'Eliminar',
      icon: 'bi-trash',
      disabled: (_) => true,
      action: (item) => { this.openDialogDelete = !this.openDialogDelete; this.reservationSelected = item; }
    },
    {
      title: "Cancelar",
      icon: "bi-x-circle",
      disabled: (item) => item.status === 'Pagado' || item.status === 'Cancelado',
      action: (item) => { this.openDialogCancel = true; this.reservationSelected = item }
    },
    {
      title: "Pagar",
      icon: "bi-cash",
      disabled: (item) => item.status === 'Pagado' || item.status === 'Cancelado',
      action: (item) => { this.onTogleDialogPay(); this.reservationSelected = item; }
    }
  ];

  public cancelReservation(item: any): void {
    this.reservationService.cancelReservation(item.id)
    .subscribe( _ => {
      this.getAll();
    })
  }

  public reservationSelected: ReservationDetail | null = null;
  public reservation: ReservationDetail | null = null;

  public openDialogDelete: boolean = false;
  public openDialogCancel: boolean = false;

  public tableModel: TableModel[] = [
    {
      name: 'id',
      title: '#',
    },
    {
      name: 'airportOrigin',
      title: 'Origen',
    },
    {
      name: 'airportDestination',
      title: 'Destino',
    },
    {
      name: 'reservationMade',
      title: 'Fecha',
    },
    {
      name: 'status',
      title: 'Estado',
    },
    {
      name: 'cost',
      title: 'Costo (USD)',
    }
  ]
  public tableData: ReservationDetail[] = [];

  cardControl = new FormControl<string>('', [Validators.required]);
  expirationControl = new FormControl<string>('', [Validators.required]);
  cvvControl = new FormControl<string>('', [Validators.required]);
  ownerControl = new FormControl<string>('', [Validators.required]);

  formGroup = new FormGroup({
    card: this.cardControl,
    expiration: this.expirationControl,
    cvv: this.cvvControl,
    owner: this.ownerControl,
  });

  onSave(): void {
    if (this.formGroup.valid && this.reservationSelected) {
      this.reservationService.payReservation(this.reservationSelected.id)
        .subscribe( reservation => {
          this.tableData = this.tableData.map(item => item.id === reservation.id ? reservation : item);
          this.formGroup.reset();
          this.onTogleDialogPay();
        })
    }
  }

  public openDialogPay: boolean = false;

  constructor(private router: Router,
    private reservationService: ReservationsService,
    private securityService: SecurityService) {}

  ngOnInit(): void {
    this.getAll();
  }

  getAll(): void {
    const id = this.securityService.currentUser?.id!;
    this.reservationService.getByPassengerId(id)
      .subscribe(response => {
        this.tableData = response;
      })
  }

  onClickItem(item: ReservationDetail): void {
    this.router.navigate(['/passenger/reservations', item.id]);
  }

  onTogleDialogPay(): void {
    this.openDialogPay = !this.openDialogPay;
  }

  onDeleteItem(result: boolean): void {
    if (result) {
      console.log(this.reservationSelected?.id!);
      // this.reservationService.delete(this.reservationSelected?.id!)
      //   .subscribe(() => {
      //     this.tableData = this.tableData.filter(item => item.id !== this.reservationSelected?.id!);
      //     this.openDialogDelete = false;
      //   })
    } this.openDialogDelete = false;
  }

  onCancelItem(result: boolean): void {
    if (result) {
      this.cancelReservation(this.reservationSelected?.id!);
    } this.openDialogCancel = false;
  }
}
