import { Component, OnInit } from '@angular/core';
import { FormControl, FormGroup, Validators } from '@angular/forms';
import { SecurityService } from '../../services/security.service';
import { SecurityCredentials } from '../../models/security-credentials.interface';
import { SecurityResponse } from '../../models/security-response.interface';
import { Router } from '@angular/router';

@Component({
  selector: 'app-sign-in',
  templateUrl: './sign-in.component.html',
  styleUrls: ['./sign-in.component.css']
})
export class SignInComponent implements OnInit {


  ngOnInit(): void {
    if (this.securityService.currentUser) {
      this.redirectToMainPage(this.securityService.currentUser.role);
    }
  }

  public lenguage: string = 'es';
  public lenguages: any[] = [
    {
      value: 'es',
      text: 'Español'
    },
    {
      value: 'en',
      text: 'English'
    }
  ];

  public text: any = {
    es: {
      email: 'Usuario o email',
      password: 'Contraseña',
      button: 'Iniciar sesión'
    },
    en: {
      email: 'Username or email',
      password: 'Password',
      button: 'Sign in'
    }
  }

  constructor(private securityService: SecurityService,
    private router: Router) {}

  public signInForm: FormGroup = new FormGroup({
    email: new FormControl<string | null>(null, [Validators.required, Validators.minLength(3)]),
    password: new FormControl<string | null>(null, [Validators.required, Validators.minLength(3)])
  });

  public showError: boolean = false;

  changeLenguage(lenguage: string) {
    this.lenguage = lenguage;
  }

  onSignIn(): void {
    this.signInForm.markAllAsTouched();
    if (this.signInForm.valid) {
      const credentials: SecurityCredentials = this.signInForm.value;
      this.securityService.login(credentials)
        .subscribe(securityResponse => {
          this.saveToLocalStorage(securityResponse);
          this.redirectToMainPage(securityResponse.role);
        }, _ => this.showError = true);
    } else this.showError = true;

  }

  redirectToMainPage(role: string): void {
    switch(role.toLowerCase()) {
      case 'supervisor':
        this.router.navigate(['/supervisors']);
        break;
      case 'agent':
        this.router.navigate(['/agents']);
        break;
      case 'passenger':
        this.router.navigate(['/passengers']);
        break;
    }
  }

  saveToLocalStorage(securityResponse: SecurityResponse): void {
    localStorage.setItem('userLogged', JSON.stringify(securityResponse));
  }
}
