import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { SecurityCredentials } from '../models/security-credentials.interface';
import { SecurityResponse } from '../models/security-response.interface';
import { Observable } from 'rxjs';
import { Router } from '@angular/router';
import { environment } from '../../../environments/environment';

@Injectable({providedIn: 'root'})
export class SecurityService {
  constructor(private http: HttpClient, private router: Router) { }

  URL_BASE: string = `${environment.url}/api/v1/auth/`;

  get currentUser(): SecurityResponse | null {
    const userLocalStorage = localStorage.getItem('userLogged');
    if (userLocalStorage == null) return null;
    return JSON.parse(userLocalStorage);
  }

  login(securityCredentials: SecurityCredentials): Observable<SecurityResponse> {
    return this.http.post<SecurityResponse>(this.URL_BASE + 'sign-in', securityCredentials);
  }

  signup(securityCredentials: SecurityCredentials): Observable<SecurityResponse> {
    return this.http.post<SecurityResponse>(this.URL_BASE + 'sign-up', securityCredentials);
  }

  logout(): void {
    localStorage.removeItem('userLogged');
    this.router.navigate(['/sign-in']);
  }
}
