import { Component, Input, OnInit } from '@angular/core';
import { TableModel } from 'src/app/shared/interfaces/table-model.interface';
import { Airline } from '../../interfaces/airline.interface';
import { DropdownElement } from 'src/app/shared/interfaces/dropdown-element-interface';
import { FormControl, Validators } from '@angular/forms';
import { AirlineService } from '../../services/airline.service';
import { AircraftService } from '../../services/aircraft.service';

@Component({
  selector: 'supervisor-base-config',
  templateUrl: './base-config.component.html',
  styleUrls: ['./base-config.component.css']
})
export class BaseConfigComponent implements OnInit {

  constructor(private airlineService: AirlineService,
    private aircraftService: AircraftService) { }

  ngOnInit(): void {
    this.getAllAirlines();
    this.getAllAircrafts();
  }

  public airlineModel: TableModel[] = [
    {
      name: 'id',
      title: '#'
    },
    {
      name: 'name',
      title: 'Nombre'
    },
    {
      name: 'code',
      title: 'Código'
    }
  ]

  public airlines: Airline[] = [];
  public aircrafts: DropdownElement[] = [];

  @Input()
  public airlineControl: FormControl<number | null> = new FormControl(null, [Validators.required]);

  @Input()
  public aircraftControl: FormControl<number | null> = new FormControl(null, [Validators.required]);

  @Input()
  public departureDateControl: FormControl<string | null> = new FormControl(null, [Validators.required]);

  @Input()
  public arrivalDateControl: FormControl<string | null> = new FormControl(null, [Validators.required]);

  getAllAirlines(): void {
    this.airlineService.getAll()
    .subscribe(airlines => this.airlines = airlines);
  }

  getAllAircrafts(): void {
    this.aircraftService.getAll()
      .subscribe(aircrafts => {
        this.aircrafts = aircrafts.map(
          aircraft => { return { value: aircraft.id, text: aircraft.name } } );
      })
  }
}
