import { Component, OnInit } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { AgentsService } from '../../services/agent.service';
import { ActivatedRoute } from '@angular/router';
import { AGENT_VALIDATORS, getAgentValidatorLenght } from '../../validators/agent.validator';
import { AgentSave, EMPTY_AGENT_SAVE } from '../../interfaces/agent.interface';
import { Location } from '@angular/common';
import { SecurityService } from 'src/app/security/services/security.service';

@Component({
  selector: 'app-agent-add',
  templateUrl: './agent-add.component.html',
  styleUrls: ['./agent-add.component.css']
})
export class AgentAddComponent implements OnInit {

  constructor(
    private location: Location,
    private activatedRouter: ActivatedRoute,
    private agentsService: AgentsService,
    private securityService: SecurityService) {}

  agentForm: FormGroup = AGENT_VALIDATORS;
  agentId?: number;


  ngOnInit(): void {
    this.activatedRouter.params.subscribe(param => {
      if (param['id']) {
        this.agentsService.getById(param['id']).subscribe(agent => this.updateValues(agent))
        this.agentId = param['id'];
      } else this.updateValues(EMPTY_AGENT_SAVE);
    });
  }

  updateValues(agent: AgentSave): void {
    this.agentForm.get('name')?.setValue(agent.name || '');
    this.agentForm.get('lastname')?.setValue(agent.lastname || '');
    this.agentForm.get('details')?.setValue(agent.details || '');
    this.agentForm.get('email')?.setValue(agent.email || '');
    this.agentForm.get('password')?.setValue(agent.password || '');
  }

  getAgentValidatorLenght(controlName: string) {
    return getAgentValidatorLenght(controlName);
  }

  onSave(): void {
    this.agentForm.markAllAsTouched();
    if (this.agentId) {
      this.agentsService.edit(this.agentId, this.agentForm.value)
        .subscribe(() => {
          this.agentForm.reset();
          this.location.back()
        });
    } else {
      this.securityService.signup({...this.agentForm.value, role: 'agent'})
        .subscribe(() => {
          this.agentForm.reset();
          this.location.back()
        });
    }
  }
}
