import { Component, OnInit } from '@angular/core';
import { PanelItem } from '../../interfaces/panel-item.interface';
import { FormControl, FormGroup, Validators } from '@angular/forms';
import { FlightScale } from '../../interfaces/flight-scale.interface';
import { FlightCost } from '../../interfaces/flight-cost.interface';
import { Flight } from '../../interfaces/flight.interface';
import { FlightSave } from '../../interfaces/flight-save.interface';
import { FlightScaleSave } from '../../interfaces/flight-scale-save.interface';
import { FlightCostSave } from '../../interfaces/flight-save-cost.interface';
import { FlightService } from '../../services/flight.service';
import { Location } from '@angular/common';
import { ActivatedRoute } from '@angular/router';

@Component({
  selector: 'app-flight-add',
  templateUrl: './flight-add.component.html',
  styleUrls: ['./flight-add.component.css']
})
export class FlightAddComponent implements OnInit {

  constructor(private flightService: FlightService,
    private location: Location,
    private activatedRoute: ActivatedRoute) { }

  ngOnInit(): void {
    this.activatedRoute.params
      .subscribe(params => {
        if (params['id']) {
          this.flightService.getById(params['id'])
            .subscribe(flight => {
              console.log(flight);
              this.flightBaseConfig.patchValue({
                airlineId: flight.airlineId,
                aircraftId: flight.aircraftId,
                departureDate: flight.departureDate,
                arrivalDate: flight.arrivalDate
              });
              this.scales = flight.legs;
              this.costs = flight.costs;
              this.isUpdated = true;
            });
        }
      })
  }

  public panelMenu: PanelItem[] = [
    {
      name: 'scales',
      title: 'Escalas',
      isActive: true,
      isVisible: true
    },
    {
      name: 'costs',
      title: 'Costos',
      isActive: false,
      isVisible: true
    }
  ];

  public airlineControl: FormControl<number | null> = new FormControl(null, [Validators.required]);
  public aircraftControl: FormControl<number | null> = new FormControl(null, [Validators.required]);
  public departureDateControl: FormControl<string | null> = new FormControl(null, [Validators.required]);
  public arrivalDateControl: FormControl<string | null> = new FormControl(null, [Validators.required]);

  public flightBaseConfig: FormGroup = new FormGroup({
    airlineId: this.airlineControl,
    aircraftId: this.aircraftControl,
    departureDate: this.departureDateControl,
    arrivalDate: this.arrivalDateControl
  });

  public scales: FlightScale[] = [];
  public costs: FlightCost[] = [];

  public isUpdated: boolean = false;

  public panelMenuActive: PanelItem = this.panelMenu[0];

  onchangeItemActive(item: PanelItem): void {
    this.panelMenuActive = item;
  }

  isInvalidForm(): boolean {
    return this.flightBaseConfig.invalid || this.scales.length === 0 || this.costs.length === 0 || this.isUpdated;
  }

  onSaveFlightConfig(): void {
    if (this.flightBaseConfig.valid && this.scales.length > 0 && this.costs.length > 0) {

      const legs: FlightScaleSave[] = this.scales.map(scale => {
        return {
          airportOriginId: scale.airportOriginId,
          airportDestinationId: scale.airportDestinationId,
          departureDateTime: scale.departureDateTime,
          arrivalDateTime: scale.arrivalDateTime
        }
      });

      const costs: FlightCostSave[] = this.costs.map(cost => {
        return {
          dateStart: cost.dateStart,
          dateEnd: cost.dateEnd,
          cost: cost.cost
        }
      });

      const flight: FlightSave = {
        airlineId: parseInt(this.flightBaseConfig.value.airlineId),
        aircraftId: parseInt(this.flightBaseConfig.value.aircraftId),
        departureDate: this.flightBaseConfig.value.departureDate,
        arrivalDate: this.flightBaseConfig.value.arrivalDate,
        legs,
        costs
      }

      this.flightService.save(flight)
        .subscribe((_: Flight) => {
          this.flightBaseConfig.reset();
          this.scales = [];
          this.costs = [];
          this.location.back();
        });
    }
  }
}
