import { Component, OnInit } from '@angular/core';
import { ResultDelete } from 'src/app/shared/interfaces/result-delete.interface';
import { TableModel } from 'src/app/shared/interfaces/table-model.interface';
import { FlightService } from '../../services/flight.service';
import { FlightTable } from '../../interfaces/flight-table.interface';
import { FormControl, FormGroup, Validators } from '@angular/forms';

@Component({
  selector: 'app-flight-config',
  templateUrl: './flight-config.component.html',
  styleUrls: ['./flight-config.component.css']
})
export class FlightConfigComponent implements OnInit {

  constructor(private flightService: FlightService) {}

  ngOnInit(): void {
    this.getFlights();
  }

  tableData: FlightTable[] = [];
  tableModel: TableModel[] = [
    {
      name: 'id',
      title: '#'
    },
    {
      name: 'airportOrigin',
      title: 'Aeropuerto origen'
    },
    {
      name: 'airportDestination',
      title: 'Aeropuerto destino',
    },
    {
      name: 'departureDate',
      title: 'Fecha de partida'
    },
    {
      name: 'arrivalDate',
      title: 'Fecha de llegada'
    }
  ];

  getFlights(): void {
    this.flightService.getAll()
      .subscribe(flights => {
        this.tableData = flights;
      });
  }

  onDeleteAgent(result: ResultDelete): void {
    if (result.result) {
      this.flightService.delete(result.id)
        .subscribe(() => {
          this.tableData = this.tableData.filter(agent => agent.id !== result.id);
        });
    }
  }
}
