import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Flight } from '../interfaces/flight.interface';
import { FlightTable } from '../interfaces/flight-table.interface';
import { FlightSave } from '../interfaces/flight-save.interface';
import { headers } from 'src/app/shared/utils/header.util';
import { environment } from 'src/environments/environment';

@Injectable({providedIn: 'root'})
export class FlightService {
  constructor(private http: HttpClient) { }

  URL_BASE: string = `${environment.url}/api/v1/flights`;

  getAll(): Observable<FlightTable[]> {
    return this.http.get<FlightTable[]>(this.URL_BASE, { headers});
  }

  searchFlight(airportOriginId: number,
    airportDestinationId: number, dateStart: string): Observable<Flight[]> {
    return this.http.get<Flight[]>(`${this.URL_BASE}/search?airportOriginId=${airportOriginId}&airportDestinationId=${airportDestinationId}&startDate=${dateStart}`, { headers });
  }

  getById(id: number): Observable<Flight> {
    return this.http.get<Flight>(`${this.URL_BASE}/${id}`, { headers });
  }

  save(flight: FlightSave): Observable<Flight> {
    return this.http.post<Flight>(this.URL_BASE, flight, { headers });
  }

  update(flight: Flight): Observable<Flight> {
    return this.http.put<Flight>(`${this.URL_BASE}/${flight.id}`, flight, { headers });
  }

  delete(id: number): Observable<Flight> {
    return this.http.delete<Flight>(`${this.URL_BASE}/${id}`, { headers });
  }
}
