CREATE SCHEMA IF NOT EXISTS flightdatabase;

USE flightdatabase;

CREATE TABLE IF NOT EXISTS roles (
    id INT NOT NULL AUTO_INCREMENT,
    name VARCHAR(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE TABLE IF NOT EXISTS users (
    id INT NOT NULL AUTO_INCREMENT,
    name VARCHAR(255) NOT NULL,
    lastname VARCHAR(255) NOT NULL,
    email VARCHAR(255) NOT NULL,
    password VARCHAR(255) NOT NULL,
    role_id INT NOT NULL,
    PRIMARY KEY (id),
    FOREIGN KEY (role_id) REFERENCES roles(id)
);

CREATE TABLE IF NOT EXISTS airports (
    id INT NOT NULL AUTO_INCREMENT,
    name VARCHAR(255) NOT NULL,
    location VARCHAR(255) NOT NULL,
    code VARCHAR(3) NOT NULL,
    PRIMARY KEY (id)
);

CREATE TABLE IF NOT EXISTS airlines (
    id INT NOT NULL AUTO_INCREMENT,
    name VARCHAR(255) NOT NULL,
    code VARCHAR(2) NOT NULL,
    PRIMARY KEY (id)
);

CREATE TABLE IF NOT EXISTS aircrafts (
    id INT NOT NULL AUTO_INCREMENT,
    name VARCHAR(255) NOT NULL,
    manufacturer VARCHAR(255) NOT NULL,
    model VARCHAR(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE TABLE IF NOT EXISTS ticket_type (
    id INT NOT NULL AUTO_INCREMENT,
    name VARCHAR(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE TABLE IF NOT EXISTS travel_class (
    id INT NOT NULL AUTO_INCREMENT,
    name VARCHAR(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE TABLE IF NOT EXISTS reservation_status (
    id INT NOT NULL AUTO_INCREMENT,
    name VARCHAR(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE TABLE IF NOT EXISTS payment_status (
    id INT NOT NULL AUTO_INCREMENT,
    name VARCHAR(255) NOT NULL,
    PRIMARY KEY (id)
);

CREATE TABLE IF NOT EXISTS supervisors (
    id INT NOT NULL AUTO_INCREMENT,
    created_at DATE NOT NULL,
    details VARCHAR(255) NOT NULL,
    user_id INT NOT NULL,
    PRIMARY KEY (id),
    FOREIGN KEY (user_id) REFERENCES users(id)
);

CREATE TABLE IF NOT EXISTS agents (
    id INT NOT NULL AUTO_INCREMENT,
    created_at DATE NOT NULL,
    details VARCHAR(255) NOT NULL,
    user_id INT NOT NULL,
    PRIMARY KEY (id),
    FOREIGN KEY (user_id) REFERENCES users(id)
);

CREATE TABLE IF NOT EXISTS passengers (
    id INT NOT NULL AUTO_INCREMENT,
    created_at DATE NOT NULL,
    address VARCHAR(255) NOT NULL,
    city VARCHAR(255) NOT NULL,
    country VARCHAR(255) NOT NULL,
    phone VARCHAR(255) NOT NULL,
    user_id INT NOT NULL,
    PRIMARY KEY (id),
    FOREIGN KEY (user_id) REFERENCES users(id)
);

INSERT INTO roles (name) VALUES ('supervisor'), ('agent'), ('passenger');

INSERT INTO airports (name, location, code)
VALUES
('Jorge Chavez International Airport', 'Lima, Peru', 'LIM'),
('John F. Kennedy International Airport', 'New York, USA', 'JFK'),
('Heathrow Airport', 'London, UK', 'LHR'),
('Charles de Gaulle Airport', 'Paris, France', 'CDG'),
('Los Angeles International Airport', 'Los Angeles, USA', 'LAX'),
('Sydney Kingsford Smith Airport', 'Sydney, Australia', 'SYD'),
('Dubai International Airport', 'Dubai, UAE', 'DXB'),
('Beijing Capital International Airport', 'Beijing, China', 'PEK'),
('Benito Juarez International Airport', 'Mexico City, Mexico', 'MEX'),
('Frankfurt Airport', 'Frankfurt, Germany', 'FRA'),
('Toronto Pearson International Airport', 'Toronto, Canada', 'YYZ'),
('Incheon International Airport', 'Seoul, South Korea', 'ICN'),
('Sao Paulo-Guarulhos International Airport', 'Sao Paulo, Brazil', 'GRU'),
('Barcelona-El Prat Airport', 'Barcelona, Spain', 'BCN'),
('Cairo International Airport', 'Cairo, Egypt', 'CAI');

INSERT INTO airlines (name, code) VALUES
    ('American Airlines', 'AA'),
    ('Delta Air Lines', 'DL'),
    ('United Airlines', 'UA'),
    ('Emirates', 'EK'),
    ('Lufthansa', 'LH'),
    ('British Airways', 'BA'),
    ('Qatar Airways', 'QR'),
    ('Air France', 'AF'),
    ('LATAM Airlines', 'LA');

INSERT INTO aircrafts (name, manufacturer, model) VALUES
    ('Boeing 737', 'Boeing', '737-800'),
    ('Airbus A320', 'Airbus', 'A320-200'),
    ('Boeing 787 Dreamliner', 'Boeing', '787-9'),
    ('Embraer E175', 'Embraer', 'E175');

INSERT INTO ticket_type (name) VALUES ('Economy'), ('Business'), ('First Class');
INSERT INTO travel_class (name) VALUES ('Economy'), ('Business'), ('First Class');
INSERT INTO reservation_status (name) VALUES ('registered'), ('processing_payment'), ('Cancelled'), ('paid');
INSERT INTO payment_status (name) VALUES ('pending'), ('paid'), ('refunded');

INSERT INTO users (email,lastname,name,password,role_id) values ("supervisor@gmail.com", "Loayza", "Roberto", "$2a$10$x2mZN5ZT0qnfUDWPFww/Ke4/UjgLRFVyEl4G/gd8kiBRZBvv4wzEO", 1);
INSERT INTO users (email,lastname,name,password,role_id) values ("agent@gmail.com", "Cordova", "Heber", "$2a$10$BFGbKrtQ67FENKMNXAR6deaICZ33m2fv4QoHMGHWlX1JNsmdR/Z5O", 2);
INSERT INTO users (email,lastname,name,password,role_id) values ("passenger@gmail.com", "DeTal", "Fulanito", "$2a$10$ks1w2U1QSCJyngLuM1X0aOnFRHa7eqG6rmb9WEOlZMjyICLhABMZe", 3);
INSERT INTO supervisors (created_at,details,user_id) values ("2023-11-08", "", 1);
INSERT INTO agents (created_at,details,user_id) values ("2023-11-08", "", 2);
INSERT INTO passengers (created_at,address, city, country, phone,user_id) values ("2023-11-08", "Calle Agusto Wiese 345", "Lima", "Peru", "987654321", 3);